@@ -18,7 +18,7 @@
 */
 
 enum { ActionNone, ActionQuit, ActionReset, ActionDisplay, ActionClear,
-	ActionPause, ActionResume };
+	ActionPause, ActionResume, ActionDNS };
 enum { DisplayReport, DisplayCurses, DisplayGTK, DisplaySplit, DisplayRaw };
 
 /*  Prototypes for display.c  */
@@ -33,3 +33,5 @@ void display_loop();
 void display_clear();
 
 extern int display_mode;
+extern int use_dns;
+extern int dns;
