@@ -150,6 +150,11 @@ void select_loop() {
       if (action == ActionResume) 
 	paused=0;
 
+      if (action == ActionDNS && dns) {
+	use_dns = !use_dns;
+	display_clear();
+      }
+
       anyset = 1;
     }
 
